# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def create_sticker_set(*, masks: bool, animated: bool, videos: bool, emojis: bool, text_color: bool, user_id: abcs.InputUser, title: str, short_name: str, thumb: Optional[abcs.InputDocument], stickers: Sequence[abcs.InputStickerSetItem], software: Optional[str]) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'g\xab!\x90')
    flags = (1 if masks else 0) | (2 if animated else 0) | (16 if videos else 0) | (32 if emojis else 0) | (64 if text_color else 0) | (0 if thumb is None else 4) | (0 if software is None else 8)
    _buffer += struct.pack('<I', flags)
    user_id._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    serialize_bytes_to(_buffer, short_name.encode('utf-8'))
    if thumb is not None:
      thumb._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(stickers))
    for _t0 in stickers:
      _t0._write_boxed_to(_buffer)
    if software is not None:
      serialize_bytes_to(_buffer, software.encode('utf-8'))
    return Request(b'' + _buffer)
def remove_sticker_from_set(*, sticker: abcs.InputDocument) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'Q\x0fv\xf7')
    sticker._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def change_sticker_position(*, sticker: abcs.InputDocument, position: int) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'\xca\xd4\xb6\xff')
    sticker._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', position)
    return Request(b'' + _buffer)
def add_sticker_to_set(*, stickerset: abcs.InputStickerSet, sticker: abcs.InputStickerSetItem) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'\xbe\xfeS\x86')
    stickerset._write_boxed_to(_buffer)
    sticker._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def set_sticker_set_thumb(*, stickerset: abcs.InputStickerSet, thumb: Optional[abcs.InputDocument], thumb_document_id: Optional[int]) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'\x92Sj\xa7')
    flags = (0 if thumb is None else 1) | (0 if thumb_document_id is None else 2)
    _buffer += struct.pack('<I', flags)
    stickerset._write_boxed_to(_buffer)
    if thumb is not None:
      thumb._write_boxed_to(_buffer)
    if thumb_document_id is not None:
      _buffer += struct.pack(f'<q', thumb_document_id)
    return Request(b'' + _buffer)
def check_short_name(*, short_name: str) -> Request[bool]:
    _buffer = bytearray(b'96K(')
    serialize_bytes_to(_buffer, short_name.encode('utf-8'))
    return Request(b'' + _buffer)
def suggest_short_name(*, title: str) -> Request[abcs.stickers.SuggestedShortName]:
    _buffer = bytearray(b'\x03\xc5\xafM')
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    return Request(b'' + _buffer)
def change_sticker(*, sticker: abcs.InputDocument, emoji: Optional[str], mask_coords: Optional[abcs.MaskCoords], keywords: Optional[str]) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'\xbc~S\xf5')
    flags = (0 if emoji is None else 1) | (0 if mask_coords is None else 2) | (0 if keywords is None else 4)
    _buffer += struct.pack('<I', flags)
    sticker._write_boxed_to(_buffer)
    if emoji is not None:
      serialize_bytes_to(_buffer, emoji.encode('utf-8'))
    if mask_coords is not None:
      mask_coords._write_boxed_to(_buffer)
    if keywords is not None:
      serialize_bytes_to(_buffer, keywords.encode('utf-8'))
    return Request(b'' + _buffer)
def rename_sticker_set(*, stickerset: abcs.InputStickerSet, title: str) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b'\x00\x1cK\x12')
    stickerset._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    return Request(b'' + _buffer)
def delete_sticker_set(*, stickerset: abcs.InputStickerSet) -> Request[bool]:
    _buffer = bytearray(b'\x94Cp\x87')
    stickerset._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
